package twhelp

import (
	"context"
	"net/http"

	"golang.org/x/time/rate"
)

//go:generate oapi-codegen -templates templates/ --config=config.yml openapi3.json

func WithUserAgent(userAgent string) ClientOption {
	return func(client *Client) error {
		client.RequestEditors = append(client.RequestEditors, func(_ context.Context, req *http.Request) error {
			req.Header.Set("User-Agent", userAgent)
			return nil
		})
		return nil
	}
}

func WithRateLimiter(rl *rate.Limiter) ClientOption {
	return func(client *Client) error {
		client.RequestEditors = append(client.RequestEditors, func(ctx context.Context, _ *http.Request) error {
			return rl.Wait(ctx)
		})
		return nil
	}
}
